@@ -99,7 +99,7 @@ proc logEdit_dayShell {{date ""} {dateFormat "YYYY-MM-DD"}} {
 
    set mmddStr [lindex $dateStr 1][lindex $dateStr 2]
    set yyyyStr [lindex $dateStr 0]
-   # thif is an unique ID for the global array "LGL_Shell"
+   # this is an unique ID for the global array "LGL_Shell"
    set idx "$yyyyStr$mmddStr"
 
    # shell already opened?
@@ -500,6 +500,13 @@ proc logEdit_loadFile idx {
 
    # read the tag file
    set entries [tag readfile $LGL_Shell($idx-file)]
+   # Seperate out the header record
+   set hdr [lindex $entries 0]
+     # Check that it is a header
+     if { [lindex [lindex $hdr 0] 0] == "Tag-worklog-version" } {
+       # preserve the header
+       set LGL_Shell($idx-header) $hdr
+       } 
    set count 0
    if {$entries != ""} {
       set defSec [clock scan "00:00:00"]
@@ -967,11 +974,17 @@ proc logEdit_shellOK {idx} {
    close $logfile
    if {[info exists LGL_Shell($idx-entries)]} {
       # output the entries to the log file
+      if {[info exists LGL_Shell($idx-header)]} {
+         set entries ""
+         lappend entries $LGL_Shell($idx-header)
+         tag writefile $fullName $entries
+         }
       tag writefile $fullName $LGL_Shell($idx-entries) "a"
    }
    if {$logfilename == $fullName} {
       if {[winfo exists .preventries.body]} {
          # update the display of previous entries
+	 readlogentries
          fillpreventries .preventries.body
       }
       # open the log file of the actual day
