@@ -12,8 +12,9 @@ package provide mainwin 0.1
 proc donext { activity { proj ""} } {
 global hh mm ss currentStart currentEnd currentActivity currentProject
 global currentAction currentActionTitle currentContact stack_info
+global currentTimeFormat
 gettime
-set currentEnd "$hh:$mm:$ss"
+set currentEnd [format $currentTimeFormat $hh $mm $ss]
 set lastId [writelog]
 .description.body delete 1.0 end
  # Cleanup variable which should be cleaned at the end
@@ -31,8 +32,8 @@ set currentAction ""
 # readlogentries
 fillpreventries .preventries.body
 gettime
-set currentStart "$hh:$mm:$ss"
-set currentEnd "$hh:$mm:$ss"
+set currentStart [format $currentTimeFormat $hh $mm $ss]
+set currentEnd [format $currentTimeFormat $hh $mm $ss]
 set currentActivity $activity
 if { $proj != "" } { set currentProject $proj }
 
@@ -52,6 +53,7 @@ set state "paused"
 
 proc doresume {} {
 global hh mm ss currentStart currentEnd state day month year
+global currentTimeFormat
 
 # We need to check on a resume to see if we are now in a different day
 # actually we may not need to - I think we can just always close and open
@@ -72,8 +74,8 @@ openlogfile
 #}
 set state "running"
 gettime
-set currentStart "$hh:$mm:$ss"
-set currentEnd "$hh:$mm:$ss"
+set currentStart [format $currentTimeFormat $hh $mm $ss]
+set currentEnd [format $currentTimeFormat $hh $mm $ss]
 
 }
 
@@ -202,6 +204,7 @@ menu .mBar.reports.m
 .mBar.reports.m add command -label [mc "Project Progress Report"] -command doProjectProgressReport
 .mBar.reports.m add command -label [mc "Interruptions Report"] -command doInterruptionsReport
 .mBar.reports.m add command -label [mc "Active and Pending Actions"] -command doActiveAndPendingReport
+.mBar.reports.m add command -label [mc "Active Actions Review"] -command doActiveActionsReview
 .mBar.reports.m add separator
 .mBar.reports.m add command -label [mc "Help"] -command "taghelp reports"
 
@@ -257,7 +260,7 @@ text .preventries.body -rel sunk -width 60 -height $history_win_depth -wrap word
 scrollbar .preventries.sb -rel sunk -command ".preventries.body yview"
 pack .preventries.body -side right -in .preventries -fill both -expand 1
 pack .preventries.sb -side right -fill y -in .preventries
-pack .preventries -fill both -expand 1
+pack .preventries -fill x
 
 
 frame .currentbar
@@ -322,7 +325,7 @@ setactionsmenu
 
 entry .actionbar.actionentry -textvariable currentActionTitle -width 40
 pack .actionbar.action .actionbar.actionentry -side left
-pack .actionbar -fill both -expand true
+pack .actionbar
 
 frame .description
 frame .description.textf
@@ -352,11 +355,12 @@ proc minuteTimer {} {
   # This is run once a minute to update the screen
  # Set the displayed end time to the current time
 global hh mm ss currentEnd state currentProject projTimes projTimesTotal projTimesTotalNonBreaks 
+global currentTimeFormat
 
 if { $state == "running" } {
  set oldmm $mm
  gettime
- set currentEnd "$hh:$mm:$ss"
+ set currentEnd [format $currentTimeFormat $hh $mm $ss]
  if {$oldmm != $mm } {
    if { $currentProject == "" } {
 	set cproj  "unknown"
