@@ -7,6 +7,28 @@
 
 package provide taglog_action 0.1
 
+proc setupActivateAfter { action } {
+# If required set up an event to activate an action after some time interval
+
+# Note that we dont worry if we are putting in an action which will happen a
+#  very long time in the future
+
+set aa [tag_entryVal $action Active-after]
+# puts "setupActivateAfter Active-after = $aa"
+if {$aa == "" } return
+
+set st [tag_entryVal $action Status]
+ if { ($st != "Blocked") && ($st != "Delegated") } return 
+
+  set timetowait [expr { [clock scan $aa] - [clock seconds] } ]
+  set timetowait [expr { $timetowait * 1000 } ]
+  set id [tag_entryVal $action Id]
+  after $timetowait "activate_timeblocked_action $id"
+
+}
+
+
+
 proc actionInputOK { w winnum { idvar ""} } {
 global year month day hh mm id_prefix
 global actin_f_a
@@ -96,6 +118,8 @@ writeallact
 
 setactionsmenu
 
+setupActivateAfter $action
+
 
 destroy $w
 
@@ -330,9 +354,16 @@ button $w.bot.ok -text [mc "Edit"] -command "actionEditOK $w 0"
 }
 button $w.bot.subtask -text [mc "Add Subtask..."] -command "addSubtask $winnum"
 button $w.bot.mail -text "Mail..." -command "actionMail $w $winnum"
+if { $mode == "edit" } {
+ button $w.bot.history -text [mc History] -command "displayHistory $actin_f_a($winnum,Id)"
+}
 button $w.bot.cancel -text [mc Cancel] -command "doCancel $w"
 button $w.bot.help -text [mc Help] -command "taghelp actinput"
-pack $w.bot.ok $w.bot.subtask $w.bot.mail $w.bot.cancel $w.bot.help -in $w.bot -side left
+pack $w.bot.ok $w.bot.subtask $w.bot.mail -in $w.bot -side left
+if { $mode == "edit" } {
+ pack $w.bot.history -in $w.bot -side left
+}
+pack $w.bot.cancel $w.bot.help -in $w.bot -side left
 
 pack $w.bot
 
@@ -342,6 +373,7 @@ tkwait window $w
 
 proc setupAutoId { winnum } {
 global actin_f_a
+global year month day hh mm
 
 if { $actin_f_a($winnum,Id) == "*Auto*" } {
  if { $actin_f_a($winnum,Project) != "" } {
@@ -516,8 +548,12 @@ global allact allactstate
 
 getallact
 
+ # set the status of actions which are active after some date to blocked unless they are
+ # Delegated, in which case they stay Delegated.
  if { $actin_f_a($winnum,Active-after) != "" } {
-   set actin_f_a($winnum,Status) Blocked
+   if { $actin_f_a($winnum,Status) != "Delegated" } {
+      set actin_f_a($winnum,Status) Blocked
+     }
    }
 
 
@@ -528,13 +564,8 @@ getallact
 
 writeallact
 
-# Note that we dont worry if we are putting in an action which will happen a
-#  very long time in the future
-if { $actin_f_a($winnum,Active-after) != "" } {
-	set timetowait [expr { [clock scan $actin_f_a($winnum,Active-after)] - [clock seconds] } ]
-	set timetowait [expr { $timetowait * 1000 } ]
-	after $timetowait "activate_timeblocked_action $actin_f_a($winnum,Id)" 
-	}
+setupActivateAfter $action
+
 return $action
 
 }
@@ -889,24 +920,80 @@ pack .hvsa$window.bot
 tkwait window .hvsa$window
 }
 
+proc doReviseAction { action redate retime summary } {
+global allact allactstate
+
+set revised 0
+if {$redate != ""} {
+if { [tag_entryVal $action Original-expected-completed-date] == "" } {
+ tag setorreplace action Original-expected-completed-date [tag_entryVal $action Expected-completed-date]
+ }
+#tag setorreplace action Revised-expected-completed-date $redate
+tag setorreplace action Expected-completed-date $redate
+set revised 1
+}
+if {$retime != ""} {
+if { [tag_entryVal $action Original-expected-time] == "" } {
+ tag setorreplace action Original-expected-time [tag_entryVal $action Expected-time]
+ }
+tag setorreplace action Expected-time $retime
+set revised 1
+}
+if {$summary !=""} {
+ tag setorreplace action Summary $summary
+ set revised 1
+}
+
+if {$revised} {
+tag setorreplace action Revised-date [clock format [clock seconds] -format "%Y-%m-%d"]
+
+set allactstate modified
+# tag update $actionsfilename $action Id
+
+foreach item $action {
+ if { [lindex $item 0] == "Id" } {
+   set thisid [lindex $item 1]
+ }
+}
+
+set test [ list Id "==" $thisid ]
+set idx 0
+foreach entry $allact {
+ if [ tag matchcond $entry $test ] {
+    set allact [lreplace $allact $idx $idx $action]
+ }
+ incr idx
+}
+
+writeallact
+
+}
+}
+
+
 proc doRevise { action i } {
-global revisedExpectedDate revisedExpectedTime actionsfilename
+global revisedExpectedDate revisedExpectedTime
 global allact allactstate
 
 set redate $revisedExpectedDate($i)
 set retime $revisedExpectedTime($i)
 set summary [string trim [.acthist$i.summary.body get 1.0 end]]
-# The snag with only reading part of the actions file is that I will have to
-# now read the whole thing to update it.
-#set actions [tag readfile $actionsfilename]
 
 set revised 0
 if {$redate != ""} {
-tag setorreplace action Revised-expected-completed-date $redate
+ if {[tag_entryVal $action Original-expected-completed-date] == ""} {
+ tag setorreplace action Original-expected-completed-date [tag_entryVal $action Expected-completed-date]
+ }
+
+#tag setorreplace action Revised-expected-completed-date $redate
+tag setorreplace action Expected-completed-date $redate
 set revised 1
 }
 if {$retime != ""} {
-tag setorreplace action Revised-expected-time $retime
+ if {[tag_entryVal $action Original-expected-time] == ""} {
+ tag setorreplace action Original-expected-time [tag_entryVal $action Expected-time]
+ }
+tag setorreplace action Expected-time $retime
 set revised 1
 }
 if {$summary !=""} {
@@ -942,7 +1029,7 @@ writeallact
 
 }
 
-proc displayHistory {} {
+proc displayHistory { {actid {}} } {
 global revisedExpectedDate revisedExpectedTime
 global actsel_filename
 
@@ -1007,6 +1094,10 @@ foreach item $action {
     set actionrevisedexpectedcompleteddate $tagvalue
   } elseif { $tagname == "Revised-expected-time" } {
     set actionrevisedexpectedtime $tagvalue
+  } elseif { $tagname == "Original-expected-time" } {
+    set actionoriginalexpectedtime $tagvalue
+  } elseif { $tagname == "Original-expected-completed-date" } {
+    set actionoriginalexpectedcompleteddate $tagvalue
   } elseif { $tagname == "Revised-date" } {
     set actionreviseddate $tagvalue
   } elseif { $tagname == "Summary" } {
@@ -1024,6 +1115,12 @@ if {! [info exist actionid ] || ! [info exist actiondate ] || ! [info exist acti
 if [info exist actionproject ] {
 .acthist$i.act.body insert end "[mc Project]: $actionproject\n"
 }
+if [info exist actionoriginalexpectedcompleteddate ] {
+ .acthist$i.act.body insert end "[mc Original-expected-completed-date]: $actionoriginalexpectedcompleteddate\n"
+}
+if [info exist actionoriginalexpectedtime ] {
+ .acthist$i.act.body insert end "[mc Original-expected-time]: $actionoriginalexpectedtime\n"
+}
 if [info exist actionexpectedcompleteddate ] {
  .acthist$i.act.body insert end "[mc Expected-completed-date]: $actionexpectedcompleteddate\n"
 }
@@ -1102,7 +1199,12 @@ if [info exist actionsummary ] {
 
 }
 
-set tests [ set_actsel_tests ]
+if { $actid != "" } {
+ set test [list Id "==" $actid]
+ lappend tests $test
+ } else {
+ set tests [ set_actsel_tests ]
+ }
 
 set actions [tag readselected $actsel_filename $tests ]
 
@@ -1114,6 +1216,8 @@ foreach action $actions {
 incr i
 }
 
+
+
 }
 
 proc setup_actsel_menus {} {
@@ -1699,7 +1803,7 @@ getallact
 
 # find all the possible candidates - only interested in actions which have
 # the Active-after field and which are blocked.
-set test [list Status "-in" { Blocked }]
+set test [list Status "-in" { Blocked Delegated }]
 lappend tests $test
 set tomorrow [clock format [clock scan tomorrow] -format "%Y-%m-%d"]
 set test [list Active-after -earlier $tomorrow]
