@@ -499,3 +499,82 @@ pack .cview.bot
 tkwait window .cview
 
 }
+
+proc importContacts {} {
+
+
+set types  [list "[list [mc "vCard Files"]] .vcf"]
+ set filename [tk_getOpenFile -filetypes $types -title [mc " vCard files to Import"]]
+
+ if {$filename !=""} {
+   set imported_contacts [read_vcard $filename]
+ }
+
+}
+
+proc read_vcard { filename } {
+#
+# Read one or more contacts from the given file and return them as a list of
+# contacts
+#
+
+set result ""
+
+set f [open $filename]
+
+while { [gets $f line] >= 0 } {
+
+# Lines should consist of a label and a value
+set ll [split $line :]
+if { [llength $ll] ==2 } {
+  set label [lindex $ll 0]
+  set value [lindex $ll 1]
+
+  puts "label is $label - value is $value"
+
+if { $label == "END"} [
+  set thiscontact ""
+  if { $imp_id==""} {
+    set imp_id Import.$now
+  }
+  set thiscontact [tagappend $thiscontact Id $imp_id]
+  set thiscontact [tagappend $thiscontact Email $imp_email]
+  set thiscontact [tagappend $thiscontact Web $imp_web]
+  set thiscontact [tagappend $thiscontact Phone $imp_phone]
+  set thiscontact [tagappend $thiscontact MobilePhone $imp_mobilephone]
+  set thiscontact [tagappend $thiscontact Fax $imp_fax]
+  set thiscontact [tagappend $thiscontact Organisation $imp_org]
+
+
+  set endpair [list End ]
+  lappend thiscontact $endpair
+
+  lappend result $thiscontact 
+  } elseif { $label == "BEGIN" } {
+  set imp_id ""
+  set imp_email ""
+  set imp_web ""
+  set imp_phone ""
+  set imp_mobilephone ""
+  set imp_fax ""
+  set imp_org ""
+
+  } elseif { $label == "ORG" } {
+    set imp_org $value
+  } elseif { $label == "URL"} {
+    set imp_web $value
+  } elseif { $label == "TEL;WORK;VOICE" } {
+   set imp_phone $value
+  } elseif { $label == "TEL;WORK;FAX" } {
+   set imp_fax $value
+
+  } else {
+  puts "llength of $ll is not 2"
+}
+
+
+}
+close $f
+return $result
+
+}
