@@ -49,6 +49,10 @@ global projects_url
 global log_summary
 global activitiesfilename
 global debug
+
+global currentTimeFormat
+set currentTimeFormat "%d:%02d:%02d"
+
 # Initialise common variables
 
 
@@ -60,8 +64,8 @@ set year 0
 set month 0
 set day 0
 getdate
-set currentStart "$hh:$mm:$ss"
-set currentEnd "$hh:$mm:$ss"
+set currentStart [format $currentTimeFormat $hh $mm $ss]
+set currentEnd [format $currentTimeFormat $hh $mm $ss]
 set currentProject ""
 set currentContact ""
 set currentAction ""
@@ -284,6 +288,11 @@ if { $dateformat_view=="DD/MM/YYYY" } {
  set dateformat_tcl "%m/%d/%Y"
  } else { set dateformat_tcl "%Y-%m-%d" }
 
+# Reset current start and end using time format from preferences,
+# so they appear correctly on boot
+set currentStart [format $currentTimeFormat $hh $mm $ss]
+set currentEnd [format $currentTimeFormat $hh $mm $ss]
+
 # Post initialisation procedures
 FindDefaultPrevday
 
@@ -362,6 +371,8 @@ global activities
 global activitiesfilename
 global libsdir editprefs_libsdir
 
+global editprefs_timeformat currentTimeFormat
+
 set activitiesfilename $editprefs_activitiesFile
 set docdir $editprefs_docdir
 set rootdir $editprefs_rootdir
@@ -379,6 +390,9 @@ if { $dateformat_view=="DD/MM/YYYY" } {
  }  elseif { $dateformat_view=="MM/DD/YYYY" } {
   set dateformat_tcl "%m/%d/%Y" 
  } else { set dateformat_tcl "%Y-%m-%d" }
+
+set currentTimeFormat $editprefs_timeformat
+ 
 if { ($history_win_depth > 1) && ( $history_win_depth <80) } {
  set history_win_depth $editprefs_history_win_depth
 }
@@ -447,6 +461,8 @@ global projects_url editprefs_projects_url
 global activitiesfilename
 global editprefs_activitiesFile
 
+global editprefs_timeformat currentTimeFormat
+
 set realprefs [file nativename $prefsfile]
 
 toplevel .editprefs
@@ -590,6 +606,18 @@ entry .editprefs.dateformat.e -textvariable editprefs_dateformat
 pack .editprefs.dateformat.l .editprefs.dateformat.e -side left -in .editprefs.dateformat
 pack .editprefs.dateformat
 
+set editprefs_timeformat $currentTimeFormat
+frame .editprefs.timeformat
+menubutton .editprefs.timeformat.l -text [mc "Time Format"] -menu .editprefs.timeformat.l.m
+menu .editprefs.timeformat.l.m
+.editprefs.timeformat.l.m add command -label [mc "Default (HH:MM:SS)"] -command "set editprefs_timeformat \"%d:%02d:%02d\""
+.editprefs.timeformat.l.m add command -label [mc "No seconds (HH:MM)"] -command "set editprefs_timeformat \"%d:%02d\""
+.editprefs.timeformat.l.m add separator
+.editprefs.timeformat.l.m add command -label [mc "Help"] -command "taghelp prefs_timeformat"
+entry .editprefs.timeformat.e -textvariable editprefs_timeformat
+pack .editprefs.timeformat.l .editprefs.timeformat.e -side left -in .editprefs.timeformat
+pack .editprefs.timeformat
+
 set editprefs_history_win_depth $history_win_depth
 frame .editprefs.history_win_depth
 menubutton .editprefs.history_win_depth.l -text [mc "History Window Depth"] -menu .editprefs.history_win_depth.l.m
@@ -734,6 +762,7 @@ global timebook_startlastweek
 global activities
 global activitiesfilename
 
+global currentTimeFormat
 
 
 set header "# Preferences for taglog"
@@ -762,6 +791,7 @@ if { $prefsfile !="" } {
  puts $f "set timebook_startlastweek $timebook_startlastweek"
  puts $f "set dateformat_view $dateformat_view"
  puts $f "set dateformat_tcl $dateformat_tcl"
+ puts $f "set currentTimeFormat $currentTimeFormat"
  puts $f "set num_today_actions $num_today_actions"
  puts $f "set history_win_depth $history_win_depth"
  puts $f "set current_win_depth $current_win_depth"
