@@ -80,6 +80,18 @@ if { [tag_entryVal $proj Name] == $projname } {
 return ""
 }
 
+proc proj_getExpectedTime { projname } {
+global allproj 
+foreach proj $allproj {
+if { [tag_entryVal $proj Name] == $projname } {
+   return [tag_entryVal $proj ExpectedTime]
+   }
+}
+return ""
+}
+
+
+
 proc projclosed { projname } {
  set enddate [getprojend $projname]
 if { $enddate != "" } {
@@ -194,7 +206,7 @@ return $results
 
 
 proc addProjectOK {} {
-global addproject_name addproject_breaks addproject_overheads addproject_bookas addproject_active addproject_immutable addproject_startdate addproject_enddate
+global addproject_name addproject_breaks addproject_overheads addproject_bookas addproject_active addproject_immutable addproject_startdate addproject_enddate addproject_expectedtime
 global allproj
 
 set endflag 1
@@ -205,6 +217,7 @@ set thisproj [tagappend $thisproj NextActionId 1]
 set thisproj [tagappend $thisproj Code $addproject_bookas]
 set thisproj [tagappend $thisproj StartDate $addproject_startdate]
 set thisproj [tagappend $thisproj EndDate $addproject_enddate]
+set thisproj [tagappend $thisproj ExpectedTime $addproject_expectedtime]
 if { $addproject_overheads } {
   set thisproj [tagappend $thisproj Flags Overheads]
   }
@@ -234,8 +247,99 @@ lappend allproj $thisproj
 destroy .addProject
 }
 
+proc inputProjectOK { w mode winnum pindex } {
+global projin_f_a allproj
+
+set proj [lindex $allproj $pindex]
+
+ tag setorreplaceflags proj Flags Breaks $projin_f_a($winnum,Breaks)
+ tag setorreplaceflags proj Flags Overheads $projin_f_a($winnum,Overheads)
+ tag setorreplace proj Code $projin_f_a($winnum,Code)
+ tag setorreplace proj StartDate $projin_f_a($winnum,StartDate)
+ tag setorreplace proj EndDate $projin_f_a($winnum,EndDate)
+ tag setorreplaceflags proj Flags Active $projin_f_a($winnum,Active)
+ tag setorreplaceflags proj Flags Immutable $projin_f_a($winnum,Immutable)
+ tag setorreplace proj ExpectedTime $projin_f_a($winnum,ExpectedTime)
+
+set allproj [lreplace $allproj $pindex $pindex $proj]
+
+destroy $w
+
+}
+
+proc projInputWindow { mode {winnum 0} {pindex -1} } {
+# At present only used to edit a project, but will merge doAddProject
+global projin_f_a
+
+set w .inpProj$winnum
+toplevel $w
+if { $mode == "input" } {
+wm title $w [mc "Add Project"]
+ } else {
+wm title $w "[mc {Edit project}] $projin_f_a($winnum,Name)"
+}
+wm minsize $w 200 200
+ 
+frame $w.entry
+label $w.entry.l -text [mc "Project name"]
+entry $w.entry.e -width 20 -textvariable projin_f_a($winnum,Name)
+pack $w.entry.l $w.entry.e -side left -in $w.entry
+pack $w.entry
+
+
+
+frame $w.flags
+set addproject_breaks 0
+checkbutton $w.flags.breaks -text [mc "Book as breaks"] -variable projin_f_a($winnum,Breaks)
+set addproject_overheads 0
+checkbutton $w.flags.overheads -text [mc "Book as overheads"] -variable projin_f_a($winnum,Overheads)
+set addproject_active 1
+checkbutton $w.flags.active -text [mc "Project is active"] -variable projin_f_a($winnum,Active)
+set addproject_immutable 0
+checkbutton $w.flags.immutable -text [mc "Project is immutable"] -variable projin_f_a($winnum,Immutable)
+pack $w.flags.breaks $w.flags.overheads $w.flags.active $w.flags.immutable -in $w.flags
+pack $w.flags
+
+
+frame $w.projcode
+label $w.projcode.project -text [mc "Booking Code"]
+entry $w.projcode.projentry -width 20 -textvariable projin_f_a($winnum,Code)
+pack $w.projcode.project $w.projcode.projentry -in $w.projcode -side left
+pack $w.projcode
+
+#set addproject_startdate [clock format [clock seconds] -format "%Y-%m-%d"]
+frame $w.start
+label $w.start.label -text [mc "Start Date"]
+calUtil_win $w.start.e "" projin_f_a($winnum,StartDate)
+pack $w.start.label $w.start.e -in $w.start -side left
+pack $w.start
+
+frame $w.end
+button $w.end.label -text [mc "End Date"] -command "taghelp project_enddate"
+calUtil_win $w.end.e "" projin_f_a($winnum,EndDate)
+pack $w.end.label $w.end.e -in $w.end -side left
+pack $w.end
+
+frame $w.expectedTime
+button $w.expectedTime.label -text [mc "Expected-time"] -command "taghelp project_expectedtime"
+entry $w.expectedTime.e -width 10 -textvariable projin_f_a($winnum,ExpectedTime)
+pack $w.expectedTime.label $w.expectedTime.e -in $w.expectedTime -side left
+pack $w.expectedTime
+
+
+frame $w.bot
+button $w.bot.ok -text OK -command "inputProjectOK $w edit $winnum $pindex"
+button $w.bot.cancel -text [mc Cancel] -command "doCancel $w"
+button $w.bot.help -text [mc Help] -command "taghelp addproject"
+pack $w.bot.ok $w.bot.cancel $w.bot.help -in $w.bot -side left
+pack $w.bot
+
+tkwait window $w
+}
+
+
 proc doAddProject {} {
-global addproject_overheads addproject_breaks addproject_bookas addproject_startdate addproject_enddate addproject_active addproject_immutable
+global addproject_overheads addproject_breaks addproject_bookas addproject_startdate addproject_enddate addproject_active addproject_immutable addproject_expectedtime
 
 toplevel .addProject
 wm title .addProject [mc "Add a new project"]
@@ -277,6 +381,13 @@ calUtil_win .addProject.end.e "" addproject_enddate
 pack .addProject.end.label .addProject.end.e -in .addProject.end -side left
 pack .addProject.end
 
+frame .addProject.expectedTime
+button .addProject.expectedTime.label -text [mc "Expected-time"] -command "taghelp project_expectedtime"
+entry .addProject.expectedTime.e -width 10 -textvariable addproject_expectedtime
+pack .addProject.expectedTime.label .addProject.expectedTime.e -in .addProject.expectedTime -side left
+pack .addProject.expectedTime
+
+
 frame .addProject.bot
 button .addProject.bot.ok -text OK -command addProjectOK
 button .addProject.bot.cancel -text [mc Cancel] -command {doCancel .addProject }
@@ -306,20 +417,13 @@ if {$epdelete($n)} {
 #   adding to them, and we want to be able to unset them too
 #
 
-# set proj [lreplace $proj 4 4 $epbreaks($n) ]
  tag setorreplaceflags proj Flags Breaks $epbreaks($n)
-# set proj [lreplace $proj 3 3 $epoverheads($n) ]
  tag setorreplaceflags proj Flags Overheads $epoverheads($n)
-# set proj [lreplace $proj 2 2 $epbookas($n)]
  tag setorreplace proj Code $epbookas($n)
-# set proj [lreplace $proj 5 5 $epstart($n)]
  tag setorreplace proj StartDate $epstart($n)
-# set proj [lreplace $proj 6 6 $epend($n)]
  tag setorreplace proj EndDate $epend($n)
-# set proj [lreplace $proj 7 7 $epactive($n)]
  tag setorreplaceflags proj Flags Active $epactive($n)
  tag setorreplaceflags proj Flags Immutable $epimmutable($n)
-# set projects [lreplace $projects $projindex $projindex $proj]
  set allproj [lreplace $allproj $projindex $projindex $proj]
 
 incr n
@@ -332,6 +436,36 @@ writeprojects
 destroy .ep
 }
 
+proc doEditProj { pname } {
+global projin_f_a
+global allproj
+
+set winnum 0
+
+set projin_f_a($winnum,Name) $pname
+set projin_f_a($winnum,Breaks) [isbreak $pname]
+set projin_f_a($winnum,Overheads) [isoverhead $pname]
+set projin_f_a($winnum,Active) [isactive $pname]
+set projin_f_a($winnum,Immutable) [isimmutable $pname]
+set projin_f_a($winnum,Code) [getprojcode $pname]
+set projin_f_a($winnum,StartDate) [getprojstart $pname]
+set projin_f_a($winnum,EndDate) [getprojend $pname]
+
+set pindex -1
+foreach proj $allproj {
+ incr pindex
+if { [tag_entryVal $proj Name] == $pname } {
+   set projin_f_a($winnum,ExpectedTime) [tag_entryVal $proj ExpectedTime]
+   break
+  }
+}
+
+
+projInputWindow edit $winnum $pindex
+
+
+}
+
 proc doEditProjects {} {
 global allproj
 global epbreaks epoverheads epbookas epdelete epstart epend epactive epimmutable
@@ -380,7 +514,7 @@ foreach proj $allproj {
  set pname [tag_entryVal $proj Name]
 
 frame .ep.m.c.f.p$n
-label .ep.m.c.f.p$n.p -text $pname -width 20
+button .ep.m.c.f.p$n.p -text $pname -width 20 -command "doEditProj \"$pname\""  
 set epbreaks($n) 0
 if { [isbreak $pname] } {
         set epbreaks($n) 1
