@@ -1,6 +1,6 @@
 #
 # taglog_report.tcl - report procedures for taglog
-# Copyright John Lines (john@paladin.demon.co.uk) July 2000
+# Copyright John Lines (john@paladin.demon.co.uk) July 2000, October 2005
 #
 # This program is released under the terms of the GNU Public Licence
 #
@@ -114,7 +114,7 @@ foreach filename $fileslist {
     
 }
 
-set resultheight [expr {[array size acttime] + 10} ]
+set resultheight [expr {[array size acttime] + 12} ]
 
 
 if { $resultheight > 20 } {
@@ -154,6 +154,11 @@ foreach act [array names acttime] {
 
 ############ end of gbarisan changes
 
+set proj_ExpectedTime [proj_getExpectedTime  $totalprojtimessel_project ]
+
+.totalprojtimesres.main.body insert end "[mc {Total Expected}]\t$proj_ExpectedTime\n"
+
+
 pack .totalprojtimesres.main
 frame .totalprojtimesres.bot
 button .totalprojtimesres.bot.ok -text OK -command {doCancel .totalprojtimesres }
@@ -1520,3 +1525,162 @@ displayActions
 
 }
 
+proc doActiveActionsReview {} {
+global allact activeactions 
+global GL_tableFont
+global CALIMAGE
+global expectedTime expectedCompleted
+
+set w .actrev
+toplevel $w
+wm title $w [mc "Active Actions Review"]
+
+frame $w.main
+text $w.main.body -rel sunk -wrap word -yscrollcommand "$w.main.sb set" -font $GL_tableFont
+scrollbar $w.main.sb -rel sunk -command "$w.main.body yview"
+pack $w.main.body -side right -in $w.main -fill both -expand 1
+pack $w.main.sb -fill y -side right -in $w.main
+pack $w.main -expand 1 -fill both
+
+set titlewidth 40
+
+$w.main.body insert end "Title\tTime\tExpected\n\n"
+
+# Note that we need to work with allact as it has all fields
+set test [list Status "-in" { Active } ]
+lappend tests $test
+set sortactiveactions [ tag extract $allact $tests ]
+
+# If an action was added directly as active then it may not have an Active-date
+# Set all the field for such actions to the date they were entered.
+#
+set idx -1
+foreach act $sortactiveactions {
+ incr idx
+if {[tag_entryVal $act Active-date] == "" } {
+  set cdate [tag_entryVal $act Date]
+  tag setorreplace act Active-date $cdate
+  set sortactiveactions [lreplace $sortactiveactions $idx $idx $act]
+
+}
+
+}
+
+for {set i 0} {$i < [llength $activeactions]} {incr i} {
+ set actionTime($i) "00:00:00"
+}
+
+set sortactiveactions [tag sort $sortactiveactions Active-date -ascii]
+
+set earliestDate [tag_entryVal [lindex $sortactiveactions 0] Active-date]
+
+set fileslist [dateRangeToLogfileList $earliestDate ""]
+
+foreach filename $fileslist {
+  set logs [tag readfile $filename]
+
+  foreach entry $logs {
+    set entryaction [tag_entryVal $entry Action]
+    if {$entryaction != ""} {
+       for {set i 0} {$i < [llength $activeactions]} {incr i} {
+	if { [lindex [lindex $activeactions $i] 0] == $entryaction } {
+           set duration [timediff [tag_entryVal $entry StartTime] [tag_entryVal $entry  EndTime]]
+#	  puts "Duration is $duration"
+	  inctime actionTime($i) $duration
+	  # and set other things for this entry
+
+         }
+
+
+      }
+
+
+    }
+
+    }
+}
+
+set i 0
+foreach action $activeactions {
+
+ set title [format "%*s" $titlewidth [string range [lindex $action 1] 0 $titlewidth]]
+ button $w.main.body.title$i -text $title -command "editaction [lindex $action 0]" -width $titlewidth
+ $w.main.body window create end -window $w.main.body.title$i
+ $w.main.body insert end "$actionTime($i)\t"
+
+ set expectedTime($i) [tag_entryVal [lindex $allact [lindex $action 4]] Expected-time]
+
+ entry $w.main.body.eTime$i -textvariable expectedTime($i) -width 5
+  $w.main.body window create end -window $w.main.body.eTime$i
+
+if { $expectedTime($i) != "" } {
+if {[expr [timediff $actionTime($i) $expectedTime($i)] < 0] } {
+ $w.main.body.eTime$i configure -background coral1 
+ }
+}
+
+ set expectedCompleted($i) [tag_entryVal [lindex $allact [lindex $action 4]] Expected-completed-date]
+
+ entry $w.main.body.ecDate$i -textvariable expectedCompleted($i) -width 16
+ 
+ button $w.main.body.ecCal$i -bitmap @$CALIMAGE \
+   -command "calUtil_open $w.main.body.ecDate$i"
+
+ $w.main.body window create end -window $w.main.body.ecDate$i
+ $w.main.body window create end -window $w.main.body.ecCal$i
+
+if { $expectedCompleted($i) != "" } {
+ if { [clock scan $expectedCompleted($i)] < [clock seconds] } {
+   $w.main.body.ecDate$i configure -background coral1
+ }
+}
+
+
+ $w.main.body insert end "\n"
+ incr i
+
+}
+
+
+frame $w.bot
+button $w.bot.ok -text OK -command "doActiveActionsReviewOK $w"
+button $w.bot.cancel -text [mc Cancel] -command "doCancel $w"
+button $w.bot.help -text [mc Help] -command "taghelp activeActionsReview"
+
+
+pack $w.bot.ok $w.bot.cancel $w.bot.help -in $w.bot -side left
+pack $w.bot
+
+tkwait window $w
+
+}
+
+proc doActiveActionsReviewOK { w } {
+global allact activeactions 
+global expectedTime expectedCompleted
+
+
+set i 0
+foreach action $activeactions {
+ set revised 0
+
+
+if { $expectedTime($i) != [tag_entryVal [lindex $allact [lindex $action 4]] Expected-time]} {
+  set revised 1
+ }
+
+if { $expectedCompleted($i) != [tag_entryVal [lindex $allact [lindex $action 4]] Expected-completed-date] } {
+ set revised 1
+ }
+
+if { $revised } {
+ doReviseAction [lindex $allact [lindex $action 4]] $expectedCompleted($i) $expectedTime($i) ""
+
+}
+
+incr i
+}
+
+
+doCancel $w
+}
